struct WorkBudget {
loop_limit: usize,
backward_jumps: usize,
loop_calls: usize,
skipped: usize,
}Expand description
Tracks budgets for control flow to limit execution time.
Fields
loop_limit: usizeMaximum number of times we can do backward jumps or loop calls.
backward_jumps: usizeCurrent number of backward jumps executed.
loop_calls: usizeCurrent number of loop call iterations executed.
skipped: usizeCounts number of instructions skipped when handling if/else conditions.
Implementations
Sourceimpl WorkBudget
impl WorkBudget
fn new(outlines: &Outlines<'_>, point_count: Option<usize>) -> Self
fn reset(&mut self)
fn doing_backward_jump(&mut self) -> Result<(), HintErrorKind>
fn doing_loop_call(&mut self, count: usize) -> Result<(), HintErrorKind>
fn skipping_instruction(&mut self) -> Result<(), HintErrorKind>